import React, { lazy, Suspense, useState, useEffect } from 'react';
import { Routes, Route, Navigate } from 'react-router-dom';
import { HelmetProvider } from 'react-helmet-async';
import { ErrorBoundary } from './components/ErrorBoundary';
import { ModalProvider } from './contexts/ModalContext';
import { ProtectedRoute } from './components/ProtectedRoute';
import { RequestInspectionPopup } from './components/RequestInspectionPopup';
import { NotFoundPage } from './pages/NotFoundPage';
import { PageTransition } from './components/PageTransition';

// Eagerly load critical pages
import HomePage from './pages/HomePage';
import { BlogPage } from './pages/BlogPage';

// Lazy load other pages
const AboutPage = lazy(() => import('./pages/AboutPage'));
const DIYTestingPage = lazy(() => import('./pages/DIYTestingPage'));
const DynamicRouter = lazy(() => import('./components/DynamicRouter').then(module => ({ default: module.DynamicRouter })));
const PartnerProgramPage = lazy(() => import('./pages/PartnerProgramPage'));
const BecomeMoldInspectorPage = lazy(() => import('./pages/BecomeMoldInspectorPage'));
const ReferrerRegistrationPage = lazy(() => import('./pages/ReferrerRegistrationPage'));
const LoginPage = lazy(() => import('./pages/LoginPage'));
const RegisterPage = lazy(() => import('./pages/RegisterPage'));
const DashboardPage = lazy(() => import('./pages/DashboardPage'));
const UserManagementPage = lazy(() => import('./pages/UserManagementPage'));
const BlogPostFormPage = lazy(() => import('./pages/BlogPostFormPage'));
const ProfilePage = lazy(() => import('./pages/ProfilePage'));
const LocationManagementPage = lazy(() => import('./pages/LocationManagementPage'));
const BlogPostPage = lazy(() => import('./pages/BlogPostPage'));
const EditBlogPostPage = lazy(() => import('./pages/EditBlogPostPage'));
const PrivacyPolicyPage = lazy(() => import('./pages/PrivacyPolicyPage'));
const ReportViewPage = lazy(() => import('./pages/ReportViewPage'));
const InspectionGuidePage = lazy(() => import('./pages/InspectionGuidePage'));
const BlogManagementPage = lazy(() => import('./pages/BlogManagementPage'));

export default function App() {
  const [showRequestPopup, setShowRequestPopup] = useState(false);
  const [referralCode, setReferralCode] = useState<string | null>(null);

  useEffect(() => {
    const params = new URLSearchParams(window.location.search);
    const code = params.get('referral');
    if (code) {
      setReferralCode(code);
      setShowRequestPopup(true);
    }
  }, []);

  return (
    <HelmetProvider>
      <ErrorBoundary>
        <div className="pt-16"> {/* Add padding to offset fixed header */}
          <ModalProvider>
          <Suspense fallback={null}>
            {showRequestPopup && (
              <RequestInspectionPopup
                onClose={() => setShowRequestPopup(false)}
                referralCode={referralCode || undefined}
              />
            )}
            <PageTransition>
              <Routes>
                {/* Eagerly loaded routes */}
                <Route path="/" element={<HomePage />} />
                <Route path="/blog" element={<BlogPage />} />

                {/* Lazy loaded routes */}
                <Route path="/about" element={<Suspense fallback={null}><AboutPage /></Suspense>} />
                <Route path="/diy-testing" element={<Suspense fallback={null}><DIYTestingPage /></Suspense>} />
                <Route path="/become-inspector" element={<Suspense fallback={null}><BecomeMoldInspectorPage /></Suspense>} />
                <Route path="/partner-program" element={<Suspense fallback={null}><PartnerProgramPage /></Suspense>} />
                <Route path="/referral-program" element={<Suspense fallback={null}><ReferrerRegistrationPage /></Suspense>} />
                <Route path="/login" element={<Suspense fallback={null}><LoginPage /></Suspense>} />
                <Route path="/register" element={<Suspense fallback={null}><RegisterPage /></Suspense>} />
                <Route path="/privacy" element={<Suspense fallback={null}><PrivacyPolicyPage /></Suspense>} />
                <Route path="/inspection-guide" element={<Suspense fallback={null}><InspectionGuidePage /></Suspense>} />
                <Route path="/*" element={<Suspense fallback={null}><DynamicRouter /></Suspense>} />
                <Route path="/report/view" element={<Suspense fallback={null}><ReportViewPage /></Suspense>} />

                {/* Protected routes */}
                <Route path="/dashboard" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <DashboardPage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                <Route path="/profile" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <ProfilePage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                <Route path="/users" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <UserManagementPage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                <Route path="/locations/manage" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <LocationManagementPage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                
                <Route path="/blog/create" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <BlogPostFormPage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                <Route path="/blog/edit/:id" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <EditBlogPostPage />
                    </Suspense>
                  </ProtectedRoute>
                } />
                <Route path="/blog/manage" element={
                  <ProtectedRoute>
                    <Suspense fallback={null}>
                      <BlogManagementPage />
                    </Suspense>
                  </ProtectedRoute>
                } />

                {/* 404 Page */}
                <Route path="*" element={<NotFoundPage />} />
              </Routes>
            </PageTransition>
          </Suspense>
        </ModalProvider>
        </div>
      </ErrorBoundary>
    </HelmetProvider>
  );
}